function [ S, C_norm ] = LorenzMie( theta, r, lambda, n_p, n_med )
%LorenzMie computes the scattering S(1,:) and S(2,:) using Lorenz-Mie theory.
%   Input is the particle radius r, the wavelength lambda, the complex
%   refractive index of the particle n_p, and the complex refractive index
%   of the medium n_med.
global A_p A_med M
psize = 2.0*pi*r/lambda;
M = terms_to_sum(n_med*psize);
A_p = A_all_n(psize*n_p, M);
A_med = A_all_n(psize*n_med, M);

cos_theta = cos(theta);
S1 = 0;
S2 = 0;
C_norm = 0;
for n = 1:M
    [a_n, b_n] = LorenzMie_ab(n, psize, n_p, n_med);
    [ pi_n, pi_nm1, pi_nm2 ] = pi_phase(n, cos_theta);
    tau_n = tau_phase(n, cos_theta, [pi_n; pi_nm1; pi_nm2]);
    S1 = S1 + (2*n + 1)/(n*(n + 1))*(a_n*pi_n + b_n*tau_n);
    S2 = S2 + (2*n + 1)/(n*(n + 1))*(a_n*tau_n + b_n*pi_n);
    C_norm = C_norm + (2*n + 1)*(sqr_norm(a_n) + sqr_norm(b_n));
end
S = [S1; S2];
C_norm = 2*pi*C_norm;
end
