% Test script for the milk function
fat_weight = 0.4;     % g/100 g
protein_weight = 3.4; % g/100 g
pressure = 0;         % MPa

% Find optical properties (per meter)
[milk_sca, milk_abs, milk_ext, milk_g] = milk(fat_weight, protein_weight, pressure);

% Find reduced scattering and extinction coefficients (per meter)
milk_red_sca = milk_sca.*(1 - milk_g);
milk_red_ext = milk_red_sca + milk_abs;

% Plot predicted absorption and reduced scattering (per mm) as a function
% of wavelength
wavelengths = 375:25:775;
clf;
[AX, H1, H2] = plotyy(wavelengths, milk_abs/1000, wavelengths, milk_red_sca/1000, 'plot', 'plot');
axes(AX(1));
ylabel('absorption coefficient (1/mm)', 'Color', 'b');
set(gca, 'YLim', [0 0.04]);
set(gca, 'YTick', 0:0.01:0.04);
axes(AX(2));
ylabel('reduced scattering coefficient (1/mm)', 'Color', 'r');
set(H1, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 2);
set(H2, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 2);
title('\bf Absorption and reduced scattering in mini milk (0.4 wt.-%) as a function of wavelength');
xlabel('wavelength (nm)');
clear AX H1 H2;