function [C_t, C_s, C_a, g, ior] = particle_props(r, lambda, n_p, n_med)
%particle_props uses Lorenz-Mie theory to find the extinction, scattering,
%and absorption cross sections (as well as asymmetry parameter and bulk
%refractive index) of a given particle in a given host medium.
global A_p A_med M
psize = 2.0*pi*r/lambda;
M = terms_to_sum(n_med*psize);
A_p = A_all_n(psize*n_p, M);
A_med = A_all_n(psize*n_med, M);

C_s = 0;    
g = 0;
S0_k = complex(0, 0);
    
[a, b] = LorenzMie_ab(1, psize, n_p, n_med);
    
n_med_sqr = n_med*n_med;
for n = 1:M-1
    a_n = a;
    b_n = b;

    tmp = 2*n + 1;
    S0_k = S0_k + tmp*(a_n + b_n)/n_med_sqr;        
    C_s = C_s + tmp*(sqr_norm(a_n) + sqr_norm(b_n));

    [a, b] = LorenzMie_ab(n + 1, psize, n_p, n_med);
      
    g = g + (n*(n + 2))/(n + 1)*(real(a_n*conj(a)) + real(b_n*conj(b)))...
          + tmp/(n*(n + 1))*real(a_n*conj(b_n));
end

scale = lambda*lambda/(2*pi);    
tmp = 2*M + 1;
S0_k = S0_k + tmp*(a + b)/n_med_sqr;
C_t = scale*real(S0_k);
C_s = C_s + tmp*(sqr_norm(a) + sqr_norm(b)); 
g = g*2/C_s;
alpha = 2*psize*imag(n_med);
C_s = C_s*scale*exp(-alpha);
if alpha > 1e-6
    C_s = C_s*alpha*alpha/(2.0*(1.0 + (alpha - 1.0)*exp(alpha)));
end
        
C_s = C_s/sqr_norm(n_med);
C_a = C_t - C_s;
ior = scale*imag(S0_k);
end

