function [ pi_n, pi_nm1, pi_nm2 ] = pi_phase( n, cos_theta )
%pi_phase computes pi_n(cos_theta) for the Lorenz-Mie scattering components.
%   Returns [pi_n pi_{n - 1} pi_{n - 2}].
global M
persistent old_n old_pi
if isempty(old_n)
    old_n = 0;
end
len = length(cos_theta);
if isempty(old_pi)
    old_pi = zeros(3, len);
end

if n == 0
    old_n = 0;
    old_pi = zeros(3, len);
    pi_n = old_pi(1,:);
elseif n == 1
    old_n = 1;
    old_pi = [ones(1, len); zeros(1, len); zeros(1, len)];
    pi_n = old_pi(1,:);
elseif n == old_n + 1
    pi_n = (2*n - 1)/(n - 1)*cos_theta.*old_pi(1,:) - n/(n - 1)*old_pi(2,:);
    old_pi = [pi_n; old_pi(1,:); old_pi(2,:)];
    if n == M
        old_n = 0;
    else
        old_n = n;
    end
elseif n ~= old_n && n ~= M
    disp('error in computation of pi_n');
end

pi_nm1 = old_pi(2,:);
pi_nm2 = old_pi(3,:);
end

