%%
% The following source code is an example of how to compute
% the phase function of individual particles using the 
% Lorenz-Mie theory presented in the SIGGRAPH 2007 paper
%
% Computing the Scattering Properties of Participating
% Media Using Lorenz-Mie Theory
%
% By authors: Jeppe Revall Frisvad
%             Niels Joergen Christensen
%             Henrik Wann Jensen
%
% Code written by Jeppe Revall Frisvad, 2013.
% Copyright (c) Jeppe Revall Frisvad 2013
%
% Permission is granted to anyone to use this code as 
% software for any purpose, including commercial applications.
% However, the software is provided 'as-is' without any warranty.
%% 

% Clear persisitent variables in Lorenz-Mie code
clear B R psi_zeta pi_phase tau_phase;

% Set wavelength and host medium refractive index
lambda = 650e-9;
n_med = complex(QuanFry(650, 20, 0), 9.32e-8);

% Choose a casein micelle
n_p = 1.503;
r = 20e-9;
theta = 0:0.01:2*pi;
[S, C_norm] = LorenzMie(theta, r, lambda, n_p, n_med);
%polar(theta, sqr_norm(S(1,:)));
%hold on;
%polar(theta, sqr_norm(S(2,:)), '--');
%hold off;
figure(1);
p = (sqr_norm(S(1,:)) + sqr_norm(S(2,:)))/(2*C_norm);
polar(theta, p);
set(findobj('Type', 'line'), 'LineWidth', 2);
title('\bf Phase function of a 20 nm casein micelle');


% Choose a fat globule
figure(2);
n_p = complex(WJ_milkfat_20dC(0.65), 5.0e-6);
r = 1e-6;
[S, C_norm] = LorenzMie(theta, r, lambda, n_p, n_med);
p = (sqr_norm(S(1,:)) + sqr_norm(S(2,:)))/(2*C_norm);
polar(theta, p);
set(findobj('Type', 'line'), 'LineWidth', 2);
title('\bf Phase function of a 1 {\mu}m fat globule');
figure(1);